@@ -6,7 +6,7 @@ use Moo;
 
 extends 'Perinci::To::PackageBase';
 
-our $VERSION = '0.22'; # VERSION
+our $VERSION = '0.23'; # VERSION
 
 sub BUILD {
     my ($self, $args) = @_;
@@ -20,17 +20,17 @@ sub _md2pod {
     $m2p->markdown_to_pod(markdown => $md);
 }
 
-sub gen_summary {
+sub doc_gen_summary {
     my ($self) = @_;
 
     my $name_summary = join(
         "",
-        $self->_parse->{name} // "",
-        ($self->_parse->{name} && $self->_parse->{summary} ? ' - ' : ''),
-        $self->_parse->{summary} // ""
+        $self->doc_parse->{name} // "",
+        ($self->doc_parse->{name} && $self->doc_parse->{summary} ? ' - ' : ''),
+        $self->doc_parse->{summary} // ""
     );
 
-    $self->add_lines(
+    $self->add_doc_lines(
         "=head1 " . uc($self->loc("Name")),
         "",
         $name_summary,
@@ -38,10 +38,10 @@ sub gen_summary {
     );
 }
 
-sub gen_version {
+sub doc_gen_version {
     my ($self) = @_;
 
-    $self->add_lines(
+    $self->add_doc_lines(
         "=head1 " . uc($self->loc("Version")),
         "",
         $self->{_meta}{pkg_version} // '?',
@@ -49,36 +49,36 @@ sub gen_version {
     );
 }
 
-sub gen_description {
+sub doc_gen_description {
     my ($self) = @_;
 
-    return unless $self->_parse->{description};
+    return unless $self->doc_parse->{description};
 
-    $self->add_lines(
+    $self->add_doc_lines(
         "=head1 " . uc($self->loc("Description")),
         "",
-        $self->_md2pod($self->_parse->{description}),
+        $self->_md2pod($self->doc_parse->{description}),
         "",
     );
 }
 
-sub _gen_function {
+sub _fdoc_gen {
     my ($self, $url) = @_;
-    my $p = $self->_parse->{functions}{$url};
+    my $p = $self->doc_parse->{functions}{$url};
 
     my $has_args = !!keys(%{$p->{args}});
 
-    $self->add_lines(
+    $self->add_doc_lines(
         "=head2 " . $p->{name} .
             ($has_args ? $p->{perl_args} : "()"). ' -> ' . $p->{human_ret},
         "");
 
-    $self->add_lines($p->{summary} . ($p->{summary} =~ /\.$/ ? "" : "."), "")
+    $self->add_doc_lines($p->{summary} . ($p->{summary} =~ /\.$/ ? "":"."), "")
         if $p->{summary};
-    $self->add_lines($self->_md2pod($p->{description}), "")
+    $self->add_doc_lines($self->_md2pod($p->{description}), "")
         if $p->{description};
     if ($has_args) {
-        $self->add_lines(
+        $self->add_doc_lines(
             $self->loc("Arguments") .
                 ' (' . $self->loc("'*' denotes required arguments") . '):',
             "",
@@ -87,7 +87,7 @@ sub _gen_function {
         );
         for my $name (sort keys %{$p->{args}}) {
             my $pa = $p->{args}{$name};
-            $self->add_lines(join(
+            $self->add_doc_lines(join(
                 "",
                 "=item * B<", $name, ">",
                 ($pa->{schema}[1]{req} ? '*' : ''), ' => ',
@@ -96,19 +96,19 @@ sub _gen_function {
                      " (" . $self->loc("default") .
                          ": $pa->{human_arg_default})" : "")
             ), "");
-            $self->add_lines(
+            $self->add_doc_lines(
                 $pa->{summary} . ($p->{summary} =~ /\.$/ ? "" : "."),
                 "") if $pa->{summary};
-            $self->add_lines(
+            $self->add_doc_lines(
                 $self->_md2pod($pa->{description}),
                 "") if $pa->{description};
         }
-        $self->add_lines("=back", "");
+        $self->add_doc_lines("=back", "");
     } else {
-        $self->add_lines($self->loc("No arguments") . ".", "");
+        $self->add_doc_lines($self->loc("No arguments") . ".", "");
     }
-    $self->add_lines($self->loc("Return value") . ':', "");
-    $self->add_lines($self->_md2pod($self->loc(join(
+    $self->add_doc_lines($self->loc("Return value") . ':', "");
+    $self->add_doc_lines($self->_md2pod($self->loc(join(
         "",
         "Returns an enveloped result (an array). ",
         "First element (status) is an integer containing HTTP status code ",
@@ -124,14 +124,14 @@ sub _gen_function {
     # XXX result description
 
     # test
-    #$self->add_lines({wrap=>0}, "Line 1\nLine 2\n");
+    #$self->add_doc_lines({wrap=>0}, "Line 1\nLine 2\n");
 }
 
-sub gen_functions {
+sub doc_gen_functions {
     my ($self) = @_;
-    my $pff = $self->_parse->{functions};
+    my $pff = $self->doc_parse->{functions};
 
-    $self->add_lines(
+    $self->add_doc_lines(
         "=head1 " . uc($self->loc("Functions")),
         "",
     );
@@ -139,13 +139,13 @@ sub gen_functions {
     # XXX categorize functions based on tags
     for my $url (sort keys %$pff) {
         my $p = $pff->{$url};
-        $self->_gen_function($url);
+        $self->_fdoc_gen($url);
     }
 
 }
 
 1;
-# ABSTRACT: Generate POD documentation from Rinci metadata
+# ABSTRACT: Generate POD documentation from Rinci package metadata
 
 
 __END__
@@ -153,11 +153,11 @@ __END__
 
 =head1 NAME
 
-Perinci::To::POD - Generate POD documentation from Rinci metadata
+Perinci::To::POD - Generate POD documentation from Rinci package metadata
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 AUTHOR
 
